<!-- markdownlint-disable MD033 MD041 -->
<h1 align="center">
    Wepipe
</h1>

<p align="center">
    <strong>A low/no-code tools for data pipeline designing, sharing, and more.</strong>
</p>

<p align="center">
    <a href="https://pypi.org/project/wepipe/" title="PyPi Version"><img src="https://img.shields.io/pypi/v/wepipe?color=green&style=flat"></a>
    <a href="https://pypi.org/project/orpyter/" title="Python Version"><img src="https://img.shields.io/badge/Python-3.8%2B-blue&style=flat"></a>
    <a href="https://github.com/weanalyze/wepipe/blob/main/LICENSE" title="Project License"><img src="https://img.shields.io/badge/License-Apache%202.0-blue.svg"></a>
</p>

<p align="center">
  <a href="#getting-started">Getting Started</a> •
  <a href="#license">License</a> •
  <a href="https://github.com/weanalyze/wepipe/releases">Changelog</a>
</p>

Turn your Python functions into pipeline. 

<sup>Pre-alpha Version: Not feature-complete and only suggested for experimental usage.</sup>

<img align="center" style="width: 80%" src="https://github.com/weanalyze/orpyter/blob/main/docs/images/orpyter-header.png?raw=true"/>

---

## Highlights

- 🔌&nbsp; Wrap multiple tasks into all-in-one pipeline.
- 📦&nbsp; Save and share configurations for reproducible analyis.
- 🧩&nbsp; Reuse pre-defined components & combine with existing pipelines.
- 📈&nbsp; Instantly deploy and scale for production usage.

## Getting Started

### Installation

> _Requirements: Python 3.8+._

```bash
pip install wepipe
```

for all features

```bash
pip install wepipe[source,pipeline,destination]
```

### Usage



## License

Apache 2.0 License.

This project is inspired by [Obsei](https://github.com/obsei/obsei) and [Opyrator](https://github.com/ml-tooling/opyrator/).